summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
authorJonathan Perkin <jonathan.perkin@oracle.com>2010-11-25 00:21:28 +0000
committerJonathan Perkin <jonathan.perkin@oracle.com>2010-11-25 00:21:28 +0000
commitddbcb7b5c4c9ea0dbac946eac5df82cb14dcbd01 (patch)
tree857dc63fd2abd1830bf5c1c1911e253cdd9ecef0 /cmake
parentf2d0f9c5f84b4a3c9a2bf80afdf000f1cc7fc22c (diff)
downloadmariadb-git-ddbcb7b5c4c9ea0dbac946eac5df82cb14dcbd01.tar.gz
Fix the .deb package prefix.
Diffstat (limited to 'cmake')
-rw-r--r--cmake/install_layout.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/install_layout.cmake b/cmake/install_layout.cmake
index 19a8a61df2d..601e208d96d 100644
--- a/cmake/install_layout.cmake
+++ b/cmake/install_layout.cmake
@@ -26,7 +26,7 @@
# Build as per default RPM layout, with prefix=/usr
#
# DEB
# Build as per STANDALONE, prefix=/opt/mysql-$major.$minor
#
# SVR4
# Solaris package layout suitable for pkg* tools, prefix=/opt/mysql/mysql
@@ -74,7 +74,7 @@ IF(UNIX)
IF(INSTALL_LAYOUT MATCHES "RPM")
SET(default_prefix "/usr")
ELSEIF(INSTALL_LAYOUT MATCHES "DEB")
- SET(default_prefix "/opt/${MYSQL_BASE_VERSION}")
+ SET(default_prefix "/opt/mysql/server-${MYSQL_BASE_VERSION}")
# This is required to avoid "cpack -GDEB" default of prefix=/usr
SET(CPACK_SET_DESTDIR ON)
ELSEIF(INSTALL_LAYOUT MATCHES "SVR4")
@@ -26,7 +26,7 @@
#
# DEB
-# Build as per STANDALONE, prefix=/opt/mysql-$major.$minor
+# Build as per STANDALONE, prefix=/opt/mysql/server-$major.$minor
#
# SVR4